@@ -63,7 +63,7 @@
 #include <dumb.h>
 #include <filesystem>
 #ifdef __WXOSX__
-	#include <ApplicationServices/ApplicationServices.h>
+#include <ApplicationServices/ApplicationServices.h>
 #endif
 
 using namespace slade;
@@ -81,9 +81,10 @@ int             temp_fail_count = 0;
 bool            init_ok         = false;
 bool            exiting         = false;
 std::thread::id main_thread_id;
+bool            win_darkmode_enabled = false;
 
 // Version
-Version version_num{ 3, 2, 6, 0 };
+Version version_num{ 3, 2, 7, 0 };
 
 // Directory paths
 string dir_data;
@@ -108,6 +109,7 @@ ResourceManager resource_manager;
 CVAR(Int, temp_location, 0, CVar::Flag::Save)
 CVAR(String, temp_location_custom, "", CVar::Flag::Save)
 CVAR(Bool, setup_wizard_run, false, CVar::Flag::Save)
+CVAR(Int, win_darkmode, 1, CVar::Flag::Save)
 
 
 // ----------------------------------------------------------------------------
@@ -486,6 +488,15 @@ bool app::init(const vector<string>& args, double ui_scale)
 	lua::init();
 #endif
 
+	// Enable dark mode in Windows if requested and supported
+#if defined(__WXMSW__) && wxCHECK_VERSION(3, 3, 0)
+	if (win_darkmode > 0)
+	{
+		win_darkmode_enabled = wxTheApp->MSWEnableDarkMode(
+			win_darkmode > 1 ? wxApp::DarkMode_Always : wxApp::DarkMode_Auto);
+	}
+#endif
+
 	// Init UI
 	ui::init(ui_scale);
 
@@ -577,19 +588,20 @@ bool app::init(const vector<string>& args, double ui_scale)
 		maineditor::windowWx()->Refresh();
 	}
 
-	// Show Accessibility Pop-Up on Mac if needed
-	#ifdef __WXOSX__
-		CFStringRef keys[] = { kAXTrustedCheckOptionPrompt };
-		CFTypeRef values[] = { kCFBooleanTrue };
-		CFDictionaryRef options = CFDictionaryCreate(NULL,
-													(const void **)&keys,
-													(const void **)&values,
-													sizeof(keys) / sizeof(keys[0]),
-													&kCFTypeDictionaryKeyCallBacks,
-													&kCFTypeDictionaryValueCallBacks);
-		if(AXIsProcessTrustedWithOptions(options))
+// Show Accessibility Pop-Up on Mac if needed
+#ifdef __WXOSX__
+	CFStringRef     keys[]   = { kAXTrustedCheckOptionPrompt };
+	CFTypeRef       values[] = { kCFBooleanTrue };
+	CFDictionaryRef options  = CFDictionaryCreate(
+        NULL,
+        (const void**)&keys,
+        (const void**)&values,
+        sizeof(keys) / sizeof(keys[0]),
+        &kCFTypeDictionaryKeyCallBacks,
+        &kCFTypeDictionaryValueCallBacks);
+	if (AXIsProcessTrustedWithOptions(options))
 		CFRelease(options);
-	#endif
+#endif
 
 	return true;
 }
@@ -776,15 +788,6 @@ bool app::useWebView()
 #endif
 }
 
-bool app::useSFMLRenderWindow()
-{
-#ifdef USE_SFML_RENDERWINDOW
-	return true;
-#else
-	return false;
-#endif
-}
-
 const string& app::iconFile()
 {
 	static string icon = "slade.ico";
@@ -800,6 +803,11 @@ bool app::isWin64Build()
 #endif
 }
 
+bool app::isDarkTheme()
+{
+	return wxSystemSettings::GetAppearance().IsDark();
+}
+
 std::thread::id app::mainThreadId()
 {
 	return main_thread_id;
