@@ -34,7 +34,10 @@ namespace app
 		unsigned long beta     = 0;
 
 		Version(unsigned long major = 0, unsigned long minor = 0, unsigned long revision = 0, unsigned long beta = 0) :
-			major{ major }, minor{ minor }, revision{ revision }, beta{ beta }
+			major{ major },
+			minor{ minor },
+			revision{ revision },
+			beta{ beta }
 		{
 		}
 
@@ -64,9 +67,9 @@ namespace app
 	};
 	Platform      platform();
 	bool          useWebView();
-	bool          useSFMLRenderWindow();
 	const string& iconFile();
 	bool          isWin64Build();
+	bool          isDarkTheme();
 
 	std::thread::id mainThreadId();
 } // namespace app
