@@ -317,9 +317,8 @@ void Configuration::readUDMFProperties(const ParseTreeNode* block, UDMFPropMap&
 // Reads a game or port definition from a parsed tree [node]. If [port_section]
 // is true it is a port definition
 // -----------------------------------------------------------------------------
-#define SET_UDMF_FEATURE(feature, field)              \
-	else if (strutil::equalCI(node->name(), #field))( \
-		udmf_features_[static_cast<unsigned>(feature)]) = node->boolValue()
+#define SET_UDMF_FEATURE(feature, field) \
+	else if (strutil::equalCI(node->name(), #field))(udmf_features_[static_cast<unsigned>(feature)]) = node->boolValue()
 #define SET_FEATURE(feature, value) supported_features_[static_cast<unsigned>(feature)] = value
 void Configuration::readGameSection(const ParseTreeNode* node_game, bool port_section)
 {
@@ -1759,16 +1758,23 @@ UDMFProperty* Configuration::getUDMFProperty(const string& name, MapObject::Type
 {
 	using Type = MapObject::Type;
 
+	UDMFPropMap* udmf_props = nullptr;
+
 	if (type == Type::Vertex)
-		return &udmf_vertex_props_[name];
+		udmf_props = &udmf_vertex_props_;
 	else if (type == Type::Line)
-		return &udmf_linedef_props_[name];
+		udmf_props = &udmf_linedef_props_;
 	else if (type == Type::Side)
-		return &udmf_sidedef_props_[name];
+		udmf_props = &udmf_sidedef_props_;
 	else if (type == Type::Sector)
-		return &udmf_sector_props_[name];
+		udmf_props = &udmf_sector_props_;
 	else if (type == Type::Thing)
-		return &udmf_thing_props_[name];
+		udmf_props = &udmf_thing_props_;
+	else
+		return nullptr;
+
+	if (udmf_props->count(name) == 1)
+		return &(*udmf_props)[name];
 	else
 		return nullptr;
 }
@@ -1791,6 +1797,26 @@ UDMFPropMap& Configuration::allUDMFProperties(MapObject::Type type)
 	}
 }
 
+// -----------------------------------------------------------------------------
+// Returns all defined UDMF properties for MapObject type [type], in the order
+// they were defined in the configuration
+// -----------------------------------------------------------------------------
+vector<std::pair<const string, UDMFProperty>*> Configuration::sortedUDMFProperties(MapObject::Type type)
+{
+	auto&                                          all_props = allUDMFProperties(type);
+	vector<std::pair<const string, UDMFProperty>*> sorted_props;
+	sorted_props.reserve(all_props.size());
+	for (auto& prop : all_props)
+	{
+		sorted_props.push_back(&prop);
+	}
+	std::sort(
+		sorted_props.begin(),
+		sorted_props.end(),
+		[](const auto& a, const auto& b) { return a->second.order() < b->second.order(); });
+	return sorted_props;
+}
+
 // -----------------------------------------------------------------------------
 // Removes any UDMF properties in [object] that have default values
 // (so they are not written to the UDMF map unnecessarily)
