@@ -33,8 +33,8 @@
 #include "Conversions.h"
 #include "Archive/Archive.h"
 #include "Archive/ArchiveEntry.h"
-#include "thirdparty/mus2mid/mus2mid.h"
-#include "thirdparty/zreaders/i_music.h"
+#include "Mus2Mid.h"
+#include "ZReaders/i_music.h"
 
 using namespace slade;
 
@@ -1308,7 +1308,7 @@ bool conversion::auSndToWav(MemChunk& in, MemChunk& out)
 
 bool conversion::voxToKvx(MemChunk& in, MemChunk& out)
 {
-#define AT(x, y, z) (((x)*length + (y)) * height + (z))
+#define AT(x, y, z) (((x) * length + (y)) * height + (z))
 
 	const uint8_t LEFT   = 1;
 	const uint8_t RIGHT  = 2;
