@@ -225,7 +225,8 @@ wxThread::ExitCode DirArchiveCheck::Entry()
 // the filters are always shown if any are defined.
 // -----------------------------------------------------------------------------
 WMFileBrowser::WMFileBrowser(wxWindow* parent, ArchiveManagerPanel* wm, int id) :
-	wxGenericDirCtrl(parent, id, wxDirDialogDefaultFolderStr), parent{ wm }
+	wxGenericDirCtrl(parent, id, wxDirDialogDefaultFolderStr),
+	parent{ wm }
 {
 	// Connect a custom event for when an item in the file tree is activated
 	auto tree_ctrl = wxGenericDirCtrl::GetTreeCtrl();
@@ -263,7 +264,8 @@ void WMFileBrowser::onItemActivated(wxTreeEvent& e)
 // ArchiveManagerPanel class constructor
 // -----------------------------------------------------------------------------
 ArchiveManagerPanel::ArchiveManagerPanel(wxWindow* parent, STabCtrl* nb_archives) :
-	DockPanel(parent), stc_archives_{ nb_archives }
+	DockPanel(parent),
+	stc_archives_{ nb_archives }
 {
 	// Create main sizer
 	auto vbox = new wxBoxSizer(wxVERTICAL);
@@ -1189,7 +1191,7 @@ void ArchiveManagerPanel::closeEntryTabs(Archive* parent) const
 void ArchiveManagerPanel::openFile(const wxString& filename) const
 {
 	// Show splash screen
-	ui::showSplash("Opening Archive...", true);
+	ui::showSplash("Opening Archive...", true, maineditor::windowWx());
 
 	// test
 	wxStopWatch sw;
@@ -1231,7 +1233,7 @@ void ArchiveManagerPanel::openFiles(const wxArrayString& files) const
 void ArchiveManagerPanel::openDirAsArchive(const wxString& dir) const
 {
 	// Show splash screen
-	ui::showSplash("Opening Directory...", true);
+	ui::showSplash("Opening Directory...", true, maineditor::windowWx());
 
 	// test
 	wxStopWatch sw;
@@ -1815,7 +1817,7 @@ bool ArchiveManagerPanel::handleAction(string_view id)
 	{
 		// Create extensions string
 		wxString extensions = app::archiveManager().getArchiveExtensionsString();
-		extensions += "|All Files (*.*)|*.*";
+		extensions += "|All Files (*.*)|*";
 
 		// Open a file browser dialog that allows multiple selection
 		// and filters by wad, zip and pk3 file extensions
@@ -2261,7 +2263,18 @@ void ArchiveManagerPanel::onDirArchiveCheckCompleted(wxThreadEvent& e)
 			// Otherwise show change/update dialog
 			else
 			{
-				DirArchiveUpdateDialog dlg(maineditor::windowWx(), archive, change_list.changes);
+				// Show on top of the focused top-level window
+				// (There's a wxGetActiveWindow, but it doesn't work on Mac.)
+				wxWindow* focused = wxWindow::FindFocus();
+				if (focused)
+				{
+					focused = wxGetTopLevelParent(focused);
+				}
+				if (!focused)
+				{
+					focused = maineditor::windowWx();
+				}
+				DirArchiveUpdateDialog dlg(focused, archive, change_list.changes);
 				dlg.ShowModal();
 			}
 
