@@ -438,6 +438,7 @@ void MapEditContext::clearMap()
 	// Clear other data
 	updateTagged();
 	info_3d_.reset();
+	renderer_.clearAnimations();
 
 	// Clear map
 	map_.clearMap();
@@ -665,9 +666,9 @@ void MapEditContext::updateTagged()
 				case TagType::Sector1Thing2:
 				{
 					int thingtag = (needs_tag == TagType::Sector1Thing2) ? arg2 : tag;
-					int sectag   = (needs_tag == TagType::Sector1Thing2) ? tag :
-								   (needs_tag == TagType::Thing1Sector2) ? arg2 :
-																		   arg3;
+					int sectag   = (needs_tag == TagType::Sector1Thing2)   ? tag
+								   : (needs_tag == TagType::Thing1Sector2) ? arg2
+																		   : arg3;
 					if ((thingtag | sectag) == 0)
 						break;
 					else if (thingtag == 0)
