@@ -92,7 +92,10 @@ EXTERN_CVAR(Int, vertex_size)
 // Renderer class constructor
 // -----------------------------------------------------------------------------
 Renderer::Renderer(MapEditContext& context) :
-	context_{ context }, renderer_2d_{ &context.map() }, renderer_3d_{ &context.map() }, view_{ true }
+	context_{ context },
+	renderer_2d_{ &context.map() },
+	renderer_3d_{ &context.map() },
+	view_{ true }
 {
 }
 
@@ -641,12 +644,8 @@ void Renderer::drawSelectionNumbers() const
 	drawing::enableTextStateReset(false);
 	drawing::setTextState(true);
 	view_.setOverlayCoords(true);
-#if USE_SFML_RENDERWINDOW && ((SFML_VERSION_MAJOR == 2 && SFML_VERSION_MINOR >= 4) || SFML_VERSION_MAJOR > 2)
-	drawing::setTextOutline(1.0f, ColRGBA::BLACK);
-#else
 	if (context_.selection().size() <= map_max_selection_numbers * 0.5)
 		drawing::setTextOutline(1.0f, ColRGBA::BLACK);
-#endif
 	for (unsigned a = 0; a < selection.size(); a++)
 	{
 		if ((int)a > map_max_selection_numbers)
@@ -1750,3 +1749,11 @@ void Renderer::addAnimation(unique_ptr<MCAnimation> animation)
 {
 	animations_.push_back(std::move(animation));
 }
+
+// -----------------------------------------------------------------------------
+// Clears all active animations
+// -----------------------------------------------------------------------------
+void Renderer::clearAnimations()
+{
+	animations_.clear();
+}
