@@ -70,10 +70,6 @@ MapCanvas::MapCanvas(wxWindow* parent, int id, MapEditContext* context) :
 	context_->setCanvas(this);
 	last_time_ = 0;
 
-#ifdef USE_SFML_RENDERWINDOW
-	setVerticalSyncEnabled(false);
-#endif
-
 	// Bind Events
 	Bind(wxEVT_SIZE, &MapCanvas::onSize, this);
 	Bind(wxEVT_KEY_DOWN, &MapCanvas::onKeyDown, this);
@@ -96,9 +92,6 @@ MapCanvas::MapCanvas(wxWindow* parent, int id, MapEditContext* context) :
 	Bind(wxEVT_SET_FOCUS, &MapCanvas::onFocus, this);
 	Bind(wxEVT_KILL_FOCUS, &MapCanvas::onFocus, this);
 	Bind(wxEVT_TIMER, &MapCanvas::onRTimer, this);
-#ifdef USE_SFML_RENDERWINDOW
-	Bind(wxEVT_IDLE, &MapCanvas::onIdle, this);
-#endif
 
 	timer_.Start(map_bg_ms);
 }
@@ -145,17 +138,11 @@ void MapCanvas::lockMouse(bool lock)
 		img.SetMask(true);
 		img.SetMaskColour(0, 0, 0);
 		SetCursor(wxCursor(img));
-#ifdef USE_SFML_RENDERWINDOW
-		setMouseCursorVisible(false);
-#endif
 	}
 	else
 	{
 		// Show cursor
 		SetCursor(wxNullCursor);
-#ifdef USE_SFML_RENDERWINDOW
-		setMouseCursorVisible(true);
-#endif
 	}
 }
 
@@ -171,9 +158,9 @@ void MapCanvas::mouseLook3d()
 		if (!overlay_current || !overlay_current->isActive() || (overlay_current && overlay_current->allow3dMlook()))
 		{
 			// Get relative mouse movement (scale with dpi on macOS and Linux)
-			const bool   useScaleFactor = (app::platform() == app::MacOS || app::platform() == app::Linux); 
-			const double scale = useScaleFactor ? GetContentScaleFactor() : 1.;
-			const double threshold = scale - 1.0;
+			const bool   useScaleFactor = (app::platform() == app::MacOS || app::platform() == app::Linux);
+			const double scale          = useScaleFactor ? GetContentScaleFactor() : 1.;
+			const double threshold      = scale - 1.0;
 
 			wxRealPoint mouse_pos = wxGetMousePosition();
 			mouse_pos.x *= scale;
@@ -201,8 +188,8 @@ void MapCanvas::mouseLook3d()
 // -----------------------------------------------------------------------------
 void MapCanvas::onKeyBindPress(string_view name)
 {
-	// Screenshot
-#ifdef USE_SFML_RENDERWINDOW
+	// Screenshot (TODO: Reimplement)
+#if 0
 	if (name == "map_screenshot")
 	{
 		// Capture shot
@@ -449,6 +436,13 @@ void MapCanvas::onMouseMotion(wxMouseEvent& e)
 // -----------------------------------------------------------------------------
 void MapCanvas::onMouseWheel(wxMouseEvent& e)
 {
+	// wxGTK has a bug causing duplicate wheel events, but the duplicates have
+	// exactly the same timestamp, which makes them easy to detect
+	if (e.GetTimestamp() == last_wheel_timestamp_)
+		return;
+	else
+		last_wheel_timestamp_ = e.GetTimestamp();
+
 #ifdef __WXOSX__
 	double mwheel_rotation = (double)e.GetWheelRotation() / (double)e.GetWheelDelta();
 	if (mwheel_rotation < 0)
