@@ -286,7 +286,7 @@ void MapEditorWindow::setupLayout()
 {
 	// Create the wxAUI manager & related things
 	auto m_mgr = new wxAuiManager(this);
-	m_mgr->SetArtProvider(new SAuiDockArt());
+	m_mgr->SetArtProvider(new SAuiDockArt(this));
 	wxAuiPaneInfo p_inf;
 
 	// Map canvas
@@ -773,7 +773,7 @@ void MapEditorWindow::buildNodes(Archive* wad)
 		return;
 
 	// Switch to ZDBSP if UDMF
-	if (mapeditor::editContext().mapDesc().format == MapFormat::UDMF && nodebuilder_id != "zdbsp")
+	if (mapeditor::editContext().mapDesc().format == MapFormat::UDMF && nodebuilder_id.value != "zdbsp")
 	{
 		wxMessageBox("Nodebuilder switched to ZDBSP for UDMF format", "Save Map", wxICON_INFORMATION);
 		builder = nodebuilders::builder("zdbsp");
