@@ -82,7 +82,8 @@ void MOPGProperty::resetValue()
 // MOPGBoolProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGBoolProperty::MOPGBoolProperty(const wxString& label, const wxString& name) :
-	MOPGProperty{ name }, wxBoolProperty(label, name, false)
+	MOPGProperty{ name },
+	wxBoolProperty(label, name, false)
 {
 }
 
@@ -152,6 +153,21 @@ void MOPGBoolProperty::applyValue()
 		object->setBoolProperty(GetName().ToStdString(), m_value.GetBool());
 }
 
+// -----------------------------------------------------------------------------
+// Sets the property value to the default
+// -----------------------------------------------------------------------------
+void MOPGBoolProperty::clearValue()
+{
+	// Do nothing if no parent (and thus no object list)
+	if (!parent_ || noupdate_)
+		return;
+
+	bool def = false;
+	if (udmf_prop_)
+		def = property::asBool(udmf_prop_->defaultValue());
+	GetGrid()->ChangePropertyValue(this, def);
+}
+
 
 // -----------------------------------------------------------------------------
 //
@@ -164,7 +180,8 @@ void MOPGBoolProperty::applyValue()
 // MOPGIntProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGIntProperty::MOPGIntProperty(const wxString& label, const wxString& name) :
-	MOPGProperty{ name }, wxIntProperty(label, name, 0)
+	MOPGProperty{ name },
+	wxIntProperty(label, name, 0)
 {
 }
 
@@ -234,6 +251,21 @@ void MOPGIntProperty::applyValue()
 		object->setIntProperty(GetName().ToStdString(), m_value.GetInteger());
 }
 
+// -----------------------------------------------------------------------------
+// Sets the property value to the default
+// -----------------------------------------------------------------------------
+void MOPGIntProperty::clearValue()
+{
+	// Do nothing if no parent (and thus no object list)
+	if (!parent_ || noupdate_)
+		return;
+
+	int def = 0;
+	if (udmf_prop_)
+		def = property::asInt(udmf_prop_->defaultValue());
+	GetGrid()->ChangePropertyValue(this, def);
+}
+
 
 // -----------------------------------------------------------------------------
 //
@@ -246,7 +278,8 @@ void MOPGIntProperty::applyValue()
 // MOPGFloatProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGFloatProperty::MOPGFloatProperty(const wxString& label, const wxString& name) :
-	MOPGProperty{ name }, wxFloatProperty(label, name, 0)
+	MOPGProperty{ name },
+	wxFloatProperty(label, name, 0)
 {
 }
 
@@ -316,6 +349,21 @@ void MOPGFloatProperty::applyValue()
 		object->setFloatProperty(GetName().ToStdString(), m_value.GetDouble());
 }
 
+// -----------------------------------------------------------------------------
+// Sets the property value to the default
+// -----------------------------------------------------------------------------
+void MOPGFloatProperty::clearValue()
+{
+	// Do nothing if no parent (and thus no object list)
+	if (!parent_ || noupdate_)
+		return;
+
+	double def = 0.;
+	if (udmf_prop_)
+		def = property::asFloat(udmf_prop_->defaultValue());
+	GetGrid()->ChangePropertyValue(this, def);
+}
+
 
 // -----------------------------------------------------------------------------
 //
@@ -328,7 +376,8 @@ void MOPGFloatProperty::applyValue()
 // MOPGStringProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGStringProperty::MOPGStringProperty(const wxString& label, const wxString& name) :
-	MOPGProperty{ name }, wxStringProperty(label, name, "")
+	MOPGProperty{ name },
+	wxStringProperty(label, name, "")
 {
 }
 
@@ -420,6 +469,21 @@ void MOPGStringProperty::applyValue()
 		object->setStringProperty(GetName().ToStdString(), m_value.GetString().ToStdString());
 }
 
+// -----------------------------------------------------------------------------
+// Sets the property value to the default
+// -----------------------------------------------------------------------------
+void MOPGStringProperty::clearValue()
+{
+	// Do nothing if no parent (and thus no object list)
+	if (!parent_ || noupdate_)
+		return;
+
+	string def;
+	if (udmf_prop_)
+		def = property::asString(udmf_prop_->defaultValue());
+	GetGrid()->ChangePropertyValue(this, def);
+}
+
 
 // -----------------------------------------------------------------------------
 // MOPGIntWithArgsProperty Class Functions
@@ -650,7 +714,8 @@ bool MOPGThingTypeProperty::OnEvent(wxPropertyGrid* propgrid, wxWindow* window,
 // MOPGLineFlagProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGLineFlagProperty::MOPGLineFlagProperty(const wxString& label, const wxString& name, int index) :
-	MOPGBoolProperty(label, name), index_{ index }
+	MOPGBoolProperty(label, name),
+	index_{ index }
 {
 }
 
@@ -720,7 +785,8 @@ void MOPGLineFlagProperty::applyValue()
 // MOPGThingFlagProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGThingFlagProperty::MOPGThingFlagProperty(const wxString& label, const wxString& name, int index) :
-	MOPGBoolProperty(label, name), index_{ index }
+	MOPGBoolProperty(label, name),
+	index_{ index }
 {
 }
 
@@ -790,7 +856,8 @@ void MOPGThingFlagProperty::applyValue()
 // MOPGAngleProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGAngleProperty::MOPGAngleProperty(const wxString& label, const wxString& name) :
-	MOPGProperty{ name }, wxEditEnumProperty(label, name)
+	MOPGProperty{ name },
+	wxEditEnumProperty(label, name)
 {
 	// Setup combo box choices
 	wxArrayString labels;
@@ -881,6 +948,21 @@ void MOPGAngleProperty::applyValue()
 		object->setIntProperty(GetName().ToStdString(), m_value.GetInteger());
 }
 
+// -----------------------------------------------------------------------------
+// Sets the property value to the default
+// -----------------------------------------------------------------------------
+void MOPGAngleProperty::clearValue()
+{
+	// Do nothing if no parent (and thus no object list)
+	if (!parent_ || noupdate_)
+		return;
+
+	int def = 0;
+	if (udmf_prop_)
+		def = property::asInt(udmf_prop_->defaultValue());
+	GetGrid()->ChangePropertyValue(this, def);
+}
+
 // -----------------------------------------------------------------------------
 // Returns the angle value as a string
 // -----------------------------------------------------------------------------
@@ -914,7 +996,8 @@ wxString MOPGAngleProperty::ValueToString(wxVariant& value, int arg_flags) const
 // MOPGColourProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGColourProperty::MOPGColourProperty(const wxString& label, const wxString& name) :
-	MOPGProperty{ name }, wxColourProperty(label, name)
+	MOPGProperty{ name },
+	wxColourProperty(label, name)
 {
 }
 
@@ -987,6 +1070,23 @@ void MOPGColourProperty::applyValue()
 		object->setIntProperty(GetName().ToStdString(), col.GetRGB());
 }
 
+// -----------------------------------------------------------------------------
+// Sets the property value to the default
+// -----------------------------------------------------------------------------
+void MOPGColourProperty::clearValue()
+{
+	// Do nothing if no parent (and thus no object list)
+	if (!parent_ || noupdate_)
+		return;
+
+	wxColour def;
+	if (udmf_prop_)
+		def.SetRGB(property::asInt(udmf_prop_->defaultValue()));
+	wxVariant var;
+	var << def;
+	GetGrid()->ChangePropertyValue(this, var);
+}
+
 
 // -----------------------------------------------------------------------------
 //
@@ -999,7 +1099,8 @@ void MOPGColourProperty::applyValue()
 // MOPGTextureProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGTextureProperty::MOPGTextureProperty(TextureType textype, const wxString& label, const wxString& name) :
-	MOPGStringProperty(label, name), textype_{ textype }
+	MOPGStringProperty(label, name),
+	textype_{ textype }
 {
 	// Set to text+button editor
 	SetEditor(wxPGEditor_TextCtrlAndButton);
@@ -1076,7 +1177,8 @@ bool MOPGTextureProperty::OnEvent(wxPropertyGrid* propgrid, wxWindow* window, wx
 // MOPGSPACTriggerProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGSPACTriggerProperty::MOPGSPACTriggerProperty(const wxString& label, const wxString& name) :
-	MOPGProperty{ name }, wxEnumProperty(label, name)
+	MOPGProperty{ name },
+	wxEnumProperty(label, name)
 {
 	// Set to combo box editor
 	SetEditor(wxPGEditor_ComboBox);
@@ -1153,6 +1255,19 @@ void MOPGSPACTriggerProperty::applyValue()
 		game::configuration().setLineSpacTrigger(GetChoiceSelection(), dynamic_cast<MapLine*>(object));
 }
 
+// -----------------------------------------------------------------------------
+// Sets the property value to the default (whatever's first)
+// -----------------------------------------------------------------------------
+void MOPGSPACTriggerProperty::clearValue()
+{
+	// Do nothing if no parent (and thus no object list)
+	if (!parent_ || noupdate_)
+		return;
+
+	int def = 0;
+	GetGrid()->ChangePropertyValue(this, 0);
+}
+
 
 // -----------------------------------------------------------------------------
 // MOPGTagProperty Class Functions
@@ -1166,7 +1281,8 @@ void MOPGSPACTriggerProperty::applyValue()
 // MOPGTagProperty class constructor
 // -----------------------------------------------------------------------------
 MOPGTagProperty::MOPGTagProperty(IdType id_type, const wxString& label, const wxString& name) :
-	MOPGIntProperty(label, name), id_type_{ id_type }
+	MOPGIntProperty(label, name),
+	id_type_{ id_type }
 {
 	// Set to text+button editor
 	SetEditor(wxPGEditor_TextCtrlAndButton);
