@@ -303,9 +303,9 @@ void ThingDirCanvas::onMouseEvent(wxMouseEvent& e)
 		{
 			// Get cursor position in canvas coordinates
 			const wxSize size = GetSize();
-			double x = -1.2 + ((double)e.GetX() / (double)size.x) * 2.4;
-			double y = -1.2 + ((double)e.GetY() / (double)size.y) * 2.4;
-			Vec2d  cursor_pos(x, y);
+			double       x    = -1.2 + ((double)e.GetX() / (double)size.x) * 2.4;
+			double       y    = -1.2 + ((double)e.GetY() / (double)size.y) * 2.4;
+			Vec2d        cursor_pos(x, y);
 
 			// Find closest dir point to cursor
 			point_hl_       = -1;
@@ -636,9 +636,9 @@ wxPanel* ThingPropsPanel::setupGeneralTab()
 		gb_sizer->AddGrowableCol(1, 1);
 
 		// 'New TID' button event
-		btn_new_id_->Bind(wxEVT_BUTTON, [&](wxCommandEvent&) {
-			text_id_->setNumber(mapeditor::editContext().map().things().firstFreeId());
-		});
+		btn_new_id_->Bind(
+			wxEVT_BUTTON,
+			[&](wxCommandEvent&) { text_id_->setNumber(mapeditor::editContext().map().things().firstFreeId()); });
 	}
 
 	return panel;
@@ -816,28 +816,31 @@ void ThingPropsPanel::applyChanges()
 	// Apply general properties
 	for (auto& object : objects_)
 	{
-		// Flags
-		if (udmf_flags_.empty())
+		if (!cb_flags_.empty())
 		{
-			for (int f = 0; f < game::configuration().nThingFlags(); f++)
+			// Flags
+			if (udmf_flags_.empty())
 			{
-				if (cb_flags_[f]->Get3StateValue() != wxCHK_UNDETERMINED)
-					game::configuration().setThingFlag(f, (MapThing*)object, cb_flags_[f]->GetValue());
+				for (int f = 0; f < game::configuration().nThingFlags(); f++)
+				{
+					if (cb_flags_[f]->Get3StateValue() != wxCHK_UNDETERMINED)
+						game::configuration().setThingFlag(f, (MapThing*)object, cb_flags_[f]->GetValue());
+				}
 			}
-		}
 
-		// UDMF flags
-		else
-		{
-			for (unsigned f = 0; f < udmf_flags_.size(); f++)
+			// UDMF flags
+			else
 			{
-				if (cb_flags_[f]->Get3StateValue() != wxCHK_UNDETERMINED)
-					object->setBoolProperty(udmf_flags_[f].ToStdString(), cb_flags_[f]->GetValue());
+				for (unsigned f = 0; f < udmf_flags_.size(); f++)
+				{
+					if (cb_flags_[f]->Get3StateValue() != wxCHK_UNDETERMINED)
+						object->setBoolProperty(udmf_flags_[f].ToStdString(), cb_flags_[f]->GetValue());
+				}
 			}
 		}
 
 		// UDMF extra flags
-		if (!udmf_flags_extra_.empty())
+		if (!udmf_flags_extra_.empty() && !cb_flags_extra_.empty())
 		{
 			for (unsigned f = 0; f < udmf_flags_extra_.size(); f++)
 			{
