@@ -31,22 +31,13 @@
 // -----------------------------------------------------------------------------
 #include "Main.h"
 #include "Drawing.h"
-#include "Archive/ArchiveManager.h"
+#include "App.h"
 #include "GLTexture.h"
-#include "General/Misc.h"
 #include "General/UI.h"
 #include "OpenGL.h"
 #include "Utility/MathStuff.h"
 #include "Utility/StringUtils.h"
 
-#ifdef __WXGTK3__
-#include <gtk-3.0/gtk/gtk.h>
-#elif __WXGTK20__
-#define GSocket GlibGSocket
-#include <gtk-2.0/gtk/gtk.h>
-#undef GSocket
-#endif
-
 using namespace slade;
 
 
@@ -143,7 +134,13 @@ void drawing::drawLineTabbed(Vec2d start, Vec2d end, double tab, double tab_max)
 // Draws a line from [p1] to [p2] with an arrowhead at the [p1] end.
 // If [twoway] is true, an arrowhead is also drawn at the [p2] end
 // -----------------------------------------------------------------------------
-void drawing::drawArrow(Vec2d p1, Vec2d p2, const ColRGBA& color, bool twoway, double arrowhead_angle, double arrowhead_length)
+void drawing::drawArrow(
+	Vec2d          p1,
+	Vec2d          p2,
+	const ColRGBA& color,
+	bool           twoway,
+	double         arrowhead_angle,
+	double         arrowhead_length)
 {
 	Vec2d  a1l, a1r, a2l, a2r;
 	Vec2d  vector = p1 - p2;
@@ -553,30 +550,10 @@ void drawing::drawHud()
 
 wxColour drawing::systemPanelBGColour()
 {
-#ifdef __WXGTK__
-	static bool     intitialized(false);
-	static wxColour bgColour(wxSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
-
-	if (!intitialized)
-	{
-		// try to get the background colour from a menu
-		GtkWidget* menu = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-		GtkStyle*  def  = gtk_rc_get_style(menu);
-		if (!def)
-			def = gtk_widget_get_default_style();
-
-		if (def)
-		{
-			GdkColor col = def->bg[GTK_STATE_NORMAL];
-			bgColour     = wxColour(col);
-		}
-		gtk_widget_destroy(menu);
-		intitialized = true;
-	}
-	return bgColour;
-#else
-	return wxSystemSettings::GetColour(wxSYS_COLOUR_3DFACE);
-#endif
+	if (app::platform() == app::Windows && app::isDarkTheme())
+		return wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW);
+	else
+		return wxSystemSettings::GetColour(wxSYS_COLOUR_3DFACE);
 }
 
 wxColour drawing::systemMenuTextColour()
