@@ -77,7 +77,6 @@ void MapSpecials::reset()
 // -----------------------------------------------------------------------------
 void MapSpecials::processMapSpecials(SLADEMap* map)
 {
-
 	// Clear out all 3D floors, or every call to this function will create duplicates!
 	// TODO this isn't a very good solution, but we don't have incremental updates yet
 	for (unsigned a = 0; a < map->nSectors(); a++)
@@ -641,10 +640,10 @@ void MapSpecials::processSRB2FOFs(const SLADEMap* map) const
 {
 	for (unsigned a = 0; a < map->nLines(); a++)
 	{
-		MapLine* line = map->line(a);
+		MapLine*   line           = map->line(a);
 		MapSector* control_sector = line->frontSector();
 
-		if(!control_sector)
+		if (!control_sector)
 			continue;
 
 		ExtraFloor extra_floor;
@@ -652,93 +651,91 @@ void MapSpecials::processSRB2FOFs(const SLADEMap* map) const
 		auto special = line->special();
 		switch (special)
 		{
-
 		//
 		//	Solid
 		//
-		case 100: //Solid, Opaque, Shadowcasting
-		case 101: //Solid, Opaque, Non-Shadowcasting
-		case 102: //Solid, Translucent
-		case 103: //Solid, Sides Only
-		case 105: //Solid, Invisible
-		case 140: //Intangible from Bottom, Opaque
-		case 141: //Intangible from Bottom, Translucent
-		case 143: //Intangible from Top, Opaque
-		case 144: //Intangible from Top, Translucent
-		case 146: //Only Tangible from Sides
-		
+		case 100: // Solid, Opaque, Shadowcasting
+		case 101: // Solid, Opaque, Non-Shadowcasting
+		case 102: // Solid, Translucent
+		case 103: // Solid, Sides Only
+		case 105: // Solid, Invisible
+		case 140: // Intangible from Bottom, Opaque
+		case 141: // Intangible from Bottom, Translucent
+		case 143: // Intangible from Top, Opaque
+		case 144: // Intangible from Top, Translucent
+		case 146: // Only Tangible from Sides
+
 		//
 		//	Intangible
 		//
-		case 120: //Water, Opaque
-		case 121: //Water, Translucent
-		case 124: //Goo Water, Translucent
-		case 220: //Intangible, Opaque
-		case 221: //Intangible, Translucent
-		case 222: //Intangible, Sides Only
-		case 223: //Intangible, Invisible
+		case 120: // Water, Opaque
+		case 121: // Water, Translucent
+		case 124: // Goo Water, Translucent
+		case 220: // Intangible, Opaque
+		case 221: // Intangible, Translucent
+		case 222: // Intangible, Sides Only
+		case 223: // Intangible, Invisible
 
 		//
 		//	Moving
 		//
-		case 150: //Air bobbing
-		case 151: //Air bobbing (Adjustable)
-		case 152: //Reverse Air Bobbing (Adjustable)
-		case 153: //Dynamically Sinking Platform
-		case 160: //Floating, Bobbing
-		case 190: //Rising Platform, Solid, Opaque, Shadowcasting
-		case 191: //Rising Platform, Solid, Opaque, Non-Shadowcasting
-		case 192: //Rising Platform, Solid, Translucent
-		case 193: //Rising Platform, Solid, Invisible
-		case 194: //Rising Platform, Intangible from Bottom, Opaque
-		case 195: //Rising Platform, Intangible from Bottom, Translucent
+		case 150: // Air bobbing
+		case 151: // Air bobbing (Adjustable)
+		case 152: // Reverse Air Bobbing (Adjustable)
+		case 153: // Dynamically Sinking Platform
+		case 160: // Floating, Bobbing
+		case 190: // Rising Platform, Solid, Opaque, Shadowcasting
+		case 191: // Rising Platform, Solid, Opaque, Non-Shadowcasting
+		case 192: // Rising Platform, Solid, Translucent
+		case 193: // Rising Platform, Solid, Invisible
+		case 194: // Rising Platform, Intangible from Bottom, Opaque
+		case 195: // Rising Platform, Intangible from Bottom, Translucent
 
 		//
 		//	Crumbling
 		//
-		case 170: //Crumbling, Respawn
-		case 171: //Crumbling, No Respawn
-		case 172: //Crumbling, Respawn, Intangible from Bottom
-		case 173: //Crumbling, No Respawn, Intangible from Bottom
-		case 174: //Crumbling, Respawn, Intangible from Bottom Translucent
-		case 175: //Crumbling, Respawn, Intangible from Bottom,Translucent
-		case 176: //Crumbling, Respawn, Floating, Bobbing
-		case 177: //Crumbling, No Respawn, Floating, Bobbing
-		case 178: //Crumbling, Respawn, Floating
-		case 179: //Crumbling, No Respawn, Floating
-		case 180: //Crumbling, Respawn, Air Bobbing
+		case 170: // Crumbling, Respawn
+		case 171: // Crumbling, No Respawn
+		case 172: // Crumbling, Respawn, Intangible from Bottom
+		case 173: // Crumbling, No Respawn, Intangible from Bottom
+		case 174: // Crumbling, Respawn, Intangible from Bottom Translucent
+		case 175: // Crumbling, Respawn, Intangible from Bottom,Translucent
+		case 176: // Crumbling, Respawn, Floating, Bobbing
+		case 177: // Crumbling, No Respawn, Floating, Bobbing
+		case 178: // Crumbling, Respawn, Floating
+		case 179: // Crumbling, No Respawn, Floating
+		case 180: // Crumbling, Respawn, Air Bobbing
 
 		//
 		//	Special
 		//
-		case 200: //Light Block
-		case 201: //Half light Block
-		case 250: //Mario Block
-		case 251: //Thwomp Block
-		case 252: //Shatter Block
-		case 253: //Shatter Block, Translucent
-		case 254: //Bustable Block
-		case 255: //Spin-Bustable Block
-		case 256: //Spin-Bustable Block, Translucent
-		case 257: //Quicksand
-		//case 258: //Laser
-		case 259: //Custom FOF
+		case 200: // Light Block
+		case 201: // Half light Block
+		case 250: // Mario Block
+		case 251: // Thwomp Block
+		case 252: // Shatter Block
+		case 253: // Shatter Block, Translucent
+		case 254: // Bustable Block
+		case 255: // Spin-Bustable Block
+		case 256: // Spin-Bustable Block, Translucent
+		case 257: // Quicksand
+		// case 258: //Laser
+		case 259: // Custom FOF
 		{
-
 			extra_floor.floor_type = ExtraFloor::SOLID;
 
 			extra_floor.effective_height = control_sector->ceiling().height;
 
-			//Side only FOFs?
-			if(special != 103 && special != 222)
+			// Side only FOFs?
+			if (special != 103 && special != 222)
 			{
-				extra_floor.ceiling_plane    = control_sector->ceiling().plane;
-				extra_floor.floor_plane      = control_sector->floor().plane;
+				extra_floor.ceiling_plane = control_sector->ceiling().plane;
+				extra_floor.floor_plane   = control_sector->floor().plane;
 			}
 			else
 			{
-				extra_floor.ceiling_plane    = Plane();
-				extra_floor.floor_plane      = Plane();
+				extra_floor.ceiling_plane = Plane();
+				extra_floor.floor_plane   = Plane();
 			}
 
 			extra_floor.control_sector_index = control_sector->index();
@@ -746,55 +743,39 @@ void MapSpecials::processSRB2FOFs(const SLADEMap* map) const
 
 			int translucency = 255;
 
-			//Translucent FOF?
-			if (
-				special == 102 
-				|| special == 141 
-				|| special == 144
-				|| special == 121
-				|| special == 124
-				|| special == 221
-				|| special == 192
-				|| special == 195
-				|| special == 174
-				|| special == 175
-				|| special == 253
+			// Translucent FOF?
+			if (special == 102 || special == 141 || special == 144 || special == 121 || special == 124 || special == 221
+				|| special == 192 || special == 195 || special == 174 || special == 175 || special == 253
 				|| special == 256)
 			{
-				translucency = 128;
-				const string &texture = line->s1()->texUpper();
+				translucency          = 128;
+				const string& texture = line->s1()->texUpper();
 
 				if (texture.size() >= 4 && texture[0] == '#')
 				{
 					errno = 0;
-					int n = std::strtol(texture.c_str()+1, NULL, 10);
+					int n = std::strtol(texture.c_str() + 1, NULL, 10);
 
 					if (errno == 0)
 						translucency = n;
 				}
-			} 
-			else if ( //Invisible FOF?
-				special == 105 
-				|| special == 223
-				|| special == 193
-				|| special == 200
-				|| special == 201
+			}
+			else if ( // Invisible FOF?
+				special == 105 || special == 223 || special == 193 || special == 200 || special == 201
 				|| special == 259)
 			{
 				translucency = 0;
 			}
 
 			extra_floor.flags = 0;
-			extra_floor.alpha = (translucency/255.f);
+			extra_floor.alpha = (translucency / 255.f);
 
-			//Only draw inside for water FOFs
+			// Only draw inside for water FOFs
 			extra_floor.draw_inside = (special >= 120 && special <= 125);
 		}
 		break;
 
-		default:
-			continue;
-		break;
+		default: continue; break;
 		}
 
 		for (auto& sector : map->sectors())
@@ -1469,15 +1450,17 @@ void MapSpecials::applyVertexHeightSlope(MapSector* target, vector<MapVertex*>&
 // (EDGE-Classic rectangular sectors only; performs additional validation)
 // -----------------------------------------------------------------------------
 template<SurfaceType T>
-void MapSpecials::applyRectangularVertexHeightSlope(MapSector* target, vector<MapVertex*>& vertices, VertexHeightMap& heights)
-	const
+void MapSpecials::applyRectangularVertexHeightSlope(
+	MapSector*          target,
+	vector<MapVertex*>& vertices,
+	VertexHeightMap&    heights) const
 {
 	std::vector<int> height_verts;
-	string prop         = (T == SurfaceType::Floor ? "zfloor" : "zceiling");
-	auto   v1_hasheight = heights.count(vertices[0]) || vertices[0]->hasProp(prop);
-	auto   v2_hasheight = heights.count(vertices[1]) || vertices[1]->hasProp(prop);
-	auto   v3_hasheight = heights.count(vertices[2]) || vertices[2]->hasProp(prop);
-	auto   v4_hasheight = heights.count(vertices[3]) || vertices[3]->hasProp(prop);
+	string           prop         = (T == SurfaceType::Floor ? "zfloor" : "zceiling");
+	auto             v1_hasheight = heights.count(vertices[0]) || vertices[0]->hasProp(prop);
+	auto             v2_hasheight = heights.count(vertices[1]) || vertices[1]->hasProp(prop);
+	auto             v3_hasheight = heights.count(vertices[2]) || vertices[2]->hasProp(prop);
+	auto             v4_hasheight = heights.count(vertices[3]) || vertices[3]->hasProp(prop);
 	if (v1_hasheight)
 		height_verts.push_back(0);
 	if (v2_hasheight)
@@ -1488,8 +1471,8 @@ void MapSpecials::applyRectangularVertexHeightSlope(MapSector* target, vector<Ma
 		height_verts.push_back(3);
 	if (height_verts.size() == 2) // Must only have two out of the four verts assigned a zfloor/ceiling value
 	{
-		MapVertex *v1 = vertices[height_verts[0]];
-		MapVertex *v2 = vertices[height_verts[1]];
+		MapVertex* v1 = vertices[height_verts[0]];
+		MapVertex* v2 = vertices[height_verts[1]];
 		// Must be both verts of the same line
 		bool same_line = false;
 		for (const auto& line : v1->connectedLines())
@@ -1503,7 +1486,11 @@ void MapSpecials::applyRectangularVertexHeightSlope(MapSector* target, vector<Ma
 		if (same_line)
 		{
 			// The zfloor/zceiling values must be equal
-			if (fabs(heights.count(v1) ? heights[v1] : vertexHeight<T>(v1, target) - heights.count(v2) ? heights[v2] : vertexHeight<T>(v2, target)) < 0.001f)
+			if (fabs(
+					heights.count(v1)                                 ? heights[v1]
+					: vertexHeight<T>(v1, target) - heights.count(v2) ? heights[v2]
+																	  : vertexHeight<T>(v2, target))
+				< 0.001f)
 			{
 				// Psuedo-Plane_Align routine
 				double     furthest_dist   = 0.0;
@@ -1537,4 +1524,4 @@ void MapSpecials::applyRectangularVertexHeightSlope(MapSector* target, vector<Ma
 			}
 		}
 	}
-}
\ No newline at end of file
+}
