@@ -277,7 +277,7 @@ void ScriptManagerWindow::setupLayout()
 
 	// Create the wxAUI manager & related things
 	auto m_mgr = new wxAuiManager(this);
-	m_mgr->SetArtProvider(new SAuiDockArt());
+	m_mgr->SetArtProvider(new SAuiDockArt(this));
 	wxAuiPaneInfo p_inf;
 
 	// Set icon
