@@ -7,13 +7,8 @@ class wxWindow;
 
 namespace slade
 {
-#ifdef USE_SFML_RENDERWINDOW
-class OGLCanvas : public wxGLCanvas, public sf::RenderWindow
-{
-#else
 class OGLCanvas : public wxGLCanvas
 {
-#endif
 public:
 	OGLCanvas(wxWindow* parent, int id, bool handle_timer = true, int timer_interval = 100);
 	~OGLCanvas() = default;
@@ -21,7 +16,6 @@ public:
 	virtual Palette& palette() { return palette_; }
 	void             setPalette(Palette* pal) { palette_.copyPalette(pal); }
 	bool             setContext();
-	bool             createSFML();
 	void             init();
 	virtual void     draw() = 0;
 	virtual void     update(long frametime) {}
@@ -29,14 +23,6 @@ public:
 	bool             setActive();
 	void             setup2D() const;
 
-#ifdef USE_SFML_RENDERWINDOW
-	bool SwapBuffers() override
-	{
-		display();
-		return true;
-	}
-#endif
-
 protected:
 	bool    init_done_ = false;
 	Palette palette_;
@@ -48,6 +34,5 @@ protected:
 	void onPaint(wxPaintEvent& e);
 	void onEraseBackground(wxEraseEvent& e);
 	void onTimer(wxTimerEvent& e);
-	void onResize(wxSizeEvent& e);
 };
 } // namespace slade
