@@ -1,7 +1,7 @@
 
 // -----------------------------------------------------------------------------
 // SLADE - It's a Doom Editor
-// Copyright(C) 2008 - 2022 Simon Judd
+// Copyright(C) 2008 - 2024 Simon Judd
 //
 // Email:       sirjuddington@gmail.com
 // Web:         http://slade.mancubus.net
@@ -33,9 +33,10 @@
 // -----------------------------------------------------------------------------
 #include "Main.h"
 #include "SAuiTabArt.h"
+#include "App.h"
 #include "Graphics/Icons.h"
 #include "OpenGL/Drawing.h"
-#include "WxUtils.h"
+#include "Utility/Colour.h"
 
 using namespace slade;
 
@@ -111,28 +112,29 @@ void IndentPressedBitmap(wxRect* rect, int button_state)
 //
 // -----------------------------------------------------------------------------
 
-SAuiTabArt::SAuiTabArt(bool close_buttons, bool main_tabs) :
-	close_buttons_{ close_buttons }, main_tabs_{ main_tabs }, padding_(tabs_condensed ? ui::scalePx(4) : ui::scalePx(8))
+SAuiTabArt::SAuiTabArt(const wxWindow* window, bool close_buttons, bool main_tabs) :
+	close_buttons_{ close_buttons },
+	main_tabs_{ main_tabs },
+	padding_(tabs_condensed ? window->FromDIP(4) : window->FromDIP(8))
 {
 	m_normalFont   = *wxNORMAL_FONT;
 	m_selectedFont = *wxNORMAL_FONT;
 
 	m_measuringFont = m_selectedFont;
-	m_fixedTabWidth = ui::scalePx(100);
+	m_fixedTabWidth = window->FromDIP(100);
 	m_tabCtrlHeight = 0;
 
 	wxColor baseColour = drawing::systemPanelBGColour();
 
 	m_activeColour       = baseColour;
 	m_baseColour         = baseColour;
-	wxColor borderColour = baseColour.ChangeLightness(75);
+	wxColor borderColour = baseColour.ChangeLightness(app::isDarkTheme() ? 115 : 75);
 	inactive_tab_colour_ = drawing::darkColour(m_baseColour, 0.95f);
 
 	m_borderPen       = wxPen(borderColour);
 	m_baseColourPen   = wxPen(m_baseColour);
 	m_baseColourBrush = wxBrush(m_baseColour);
 
-#if wxCHECK_VERSION(3, 1, 6)
 	m_activeCloseBmp    = icons::getInterfaceIcon("cross");
 	close_bitmap_white_ = icons::getInterfaceIcon("cross", -1, icons::Dark);
 	m_disabledCloseBmp  = icons::getInterfaceIcon("cross");
@@ -145,20 +147,6 @@ SAuiTabArt::SAuiTabArt(bool close_buttons, bool main_tabs) :
 
 	m_activeWindowListBmp   = icons::getInterfaceIcon("arrow-down");
 	m_disabledWindowListBmp = icons::getInterfaceIcon("arrow-down");
-#else
-	m_activeCloseBmp    = icons::getInterfaceIcon("cross");
-	close_bitmap_white_ = icons::getInterfaceIcon("cross", -1, icons::Dark);
-	m_disabledCloseBmp  = icons::getInterfaceIcon("cross").ConvertToDisabled();
-
-	m_activeLeftBmp   = icons::getInterfaceIcon("arrow-left");
-	m_disabledLeftBmp = icons::getInterfaceIcon("arrow-left").ConvertToDisabled();
-
-	m_activeRightBmp   = icons::getInterfaceIcon("arrow-right");
-	m_disabledRightBmp = icons::getInterfaceIcon("arrow-right").ConvertToDisabled();
-
-	m_activeWindowListBmp   = icons::getInterfaceIcon("arrow-down");
-	m_disabledWindowListBmp = icons::getInterfaceIcon("arrow-down").ConvertToDisabled();
-#endif
 
 	m_flags = 0;
 }
@@ -172,55 +160,53 @@ wxAuiTabArt* SAuiTabArt::Clone()
 
 void SAuiTabArt::DrawBorder(wxDC& dc, wxWindow* wnd, const wxRect& rect)
 {
-	int    height = ((wxAuiNotebook*)wnd)->GetTabCtrlHeight(); // -3;
+	auto   notebook = dynamic_cast<wxAuiNotebook*>(wnd);
+	int    height   = notebook->GetTabCtrlHeight(); // -3;
 	wxRect theRect(rect);
 
+	dc.SetPen(m_borderPen);
 	dc.DrawLine(theRect.x, theRect.y + height, theRect.x, theRect.y + theRect.height);
 	dc.DrawLine(
 		theRect.x + theRect.width - 1, theRect.y + height, theRect.x + theRect.width - 1, theRect.y + theRect.height);
 	dc.DrawLine(theRect.x, theRect.y + theRect.height - 1, theRect.x + theRect.width, theRect.y + theRect.height - 1);
-
-	dc.SetPen(wxPen((main_tabs_ && global::win_version_major >= 10) ? col_w10_bg : m_baseColour));
 	dc.DrawLine(theRect.x, theRect.y, theRect.x, theRect.y + height);
+
+	dc.SetPen(wxPen(wnd->GetBackgroundColour(), wnd->FromDIP(2)));
 	dc.DrawLine(theRect.x + theRect.width - 1, theRect.y, theRect.x + theRect.width - 1, theRect.y + height);
 	dc.DrawLine(theRect.x, theRect.y, theRect.x + theRect.width, theRect.y);
+	dc.DrawLine(theRect.x, theRect.y, theRect.x, theRect.y + wnd->FromDIP(3));
 }
 
-void SAuiTabArt::DrawBackground(wxDC& dc, wxWindow* WXUNUSED(wnd), const wxRect& rect)
+void SAuiTabArt::DrawBackground(wxDC& dc, wxWindow* wnd, const wxRect& rect)
 {
-	// draw background
-	wxColor top_color    = (main_tabs_ && global::win_version_major >= 10) ? col_w10_bg : m_baseColour;
-	wxColor bottom_color = (main_tabs_ && global::win_version_major >= 10) ? col_w10_bg : m_baseColour;
-	wxRect  r;
+	auto px1 = wnd->FromDIP(1);
+	auto px2 = wnd->FromDIP(2);
+	auto px4 = wnd->FromDIP(4);
 
-	auto px1 = static_cast<int>(ui::scaleFactor());
-	auto px2 = ui::scalePx(2);
-	auto px4 = ui::scalePx(4);
+	bool w10_light_bg = main_tabs_ && !app::isDarkTheme() && app::platform() == app::Windows;
 
+	// Background
+	wxRect r;
 	if (m_flags & wxAUI_NB_BOTTOM)
 		r = wxRect(rect.x, rect.y, rect.width + px2, rect.height);
 	else
 		r = wxRect(rect.x, rect.y, rect.width + px2, rect.height);
+	dc.SetBrush(wxBrush(w10_light_bg ? col_w10_bg : wnd->GetBackgroundColour()));
+	dc.SetPen(*wxTRANSPARENT_PEN);
+	dc.DrawRectangle(r);
 
-	dc.GradientFillLinear(r, top_color, bottom_color, wxSOUTH);
-
-	// draw base lines
+	// Base lines
 	dc.SetPen(wxPen(m_baseColour));
 	int y = rect.GetHeight();
 	int w = rect.GetWidth();
 
 	if (m_flags & wxAUI_NB_BOTTOM)
 	{
-		dc.SetBrush(wxBrush(bottom_color));
+		dc.SetBrush(wxBrush(m_baseColour));
 		dc.DrawRectangle(-px1, 0, w + px2, px4);
 	}
 	else
 	{
-		// dc.SetPen(*wxTRANSPARENT_PEN);
-		// dc.SetBrush(wxBrush(m_activeColour));
-		// dc.SetBrush(wxBrush(wxColor(224, 238, 255)));
-		// dc.DrawRectangle(-1, y - 4, w + 2, 4);
-
 		dc.SetPen(m_borderPen);
 		dc.DrawLine(-px2, y - px1, w + px2, y - px1);
 	}
@@ -255,6 +241,9 @@ void SAuiTabArt::DrawTab(
 	if (caption.empty())
 		caption = wxT("Xj");
 
+	// Regular tab control titles require double ampersands to show a single one, emulate that here
+	caption.Replace("&&", "&");
+
 	dc.SetFont(m_selectedFont);
 	dc.GetTextExtent(caption, &selected_textx, &selected_texty);
 
@@ -266,13 +255,13 @@ void SAuiTabArt::DrawTab(
 		bluetab = true;
 
 	// figure out the size of the tab
-	wxSize tab_size = GetTabSize(dc, wnd, page.caption, page.bitmap, page.active, close_button_state, x_extent);
+	wxSize tab_size = GetTabSize(dc, wnd, caption, page.bitmap, page.active, close_button_state, x_extent);
 
 	// I know :P This stuff should probably be completely rewritten,
 	// but this will do for now
-	auto px2 = ui::scalePxU(2);
-	auto px3 = ui::scalePxU(3);
-	auto px4 = ui::scalePxU(4);
+	auto px2 = wnd->FromDIP(2);
+	auto px3 = wnd->FromDIP(3);
+	auto px4 = wnd->FromDIP(4);
 
 	wxCoord tab_height = m_tabCtrlHeight + px2;
 	wxCoord tab_width  = tab_size.x;
@@ -286,7 +275,8 @@ void SAuiTabArt::DrawTab(
 		tab_y += px2;
 	}
 
-	caption = page.caption;
+	if (page.caption.empty())
+		caption = page.caption;
 
 
 	// select pen, brush and font for the tab to be drawn
@@ -305,7 +295,7 @@ void SAuiTabArt::DrawTab(
 	// create points that will make the tab outline
 	int clip_width = tab_width;
 	if (tab_x + clip_width > in_rect.x + in_rect.width)
-		clip_width = (in_rect.x + in_rect.width) - tab_x;
+		clip_width = in_rect.x + in_rect.width - tab_x;
 	dc.SetClippingRegion(tab_x, tab_y, clip_width + 1, tab_height - px3);
 
 	wxPoint border_points[6];
@@ -337,7 +327,7 @@ void SAuiTabArt::DrawTab(
 	if (page.active)
 	{
 		// draw active tab
-		bgcol = m_activeColour;
+		bgcol = bluetab ? bluetab_colour : m_activeColour;
 
 		// draw base background color
 		wxRect r(tab_x, tab_y, tab_width, tab_height);
@@ -348,20 +338,23 @@ void SAuiTabArt::DrawTab(
 		// highlight top of tab
 		if (!bluetab)
 		{
+#ifdef __WXMSW__
+			auto col_hilight = wxColour(app::isDarkTheme() ? "#6696FF" : "#476DBD");
+#else
 			wxColour col_hilight = wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHT);
+#endif
 			dc.SetPen(*wxTRANSPARENT_PEN);
 			dc.SetBrush(wxBrush(col_hilight));
-			dc.DrawRectangle(r.x + 1, r.y + 1, r.width - 1, px2);
+			dc.DrawRectangle(r.x + 1, r.y + 1, r.width - 1, px3);
 		}
 	}
 	else
 	{
 		bgcol = inactive_tab_colour_;
 
-		wxRect  r(tab_x, tab_y, tab_width, tab_height);
-		wxPoint mouse = wnd->ScreenToClient(wxGetMousePosition());
+		wxRect r(tab_x, tab_y, tab_width, tab_height);
 		dc.SetPen(wxPen(inactive_tab_colour_));
-		dc.SetBrush(wxBrush(inactive_tab_colour_));
+		dc.SetBrush(wxBrush(page.hover ? m_baseColour : inactive_tab_colour_));
 		dc.DrawRectangle(r.x + 1, r.y + 1, r.width - 1, r.height - px4);
 	}
 
@@ -384,16 +377,8 @@ void SAuiTabArt::DrawTab(
 	// draw icon if set
 	if (page.bitmap.IsOk())
 	{
-#if wxCHECK_VERSION(3, 1, 6)
 		const auto& bmp = page.bitmap.GetBitmapFor(wnd);
-		dc.DrawBitmap(bmp, tab_x + padding_, drawn_tab_yoff + (drawn_tab_height / 2) - (bmp.GetHeight() / 2), true);
-#else
-		dc.DrawBitmap(
-			page.bitmap,
-			tab_x + padding_,
-			drawn_tab_yoff + (drawn_tab_height / 2) - (page.bitmap.GetHeight() / 2),
-			true);
-#endif
+		dc.DrawBitmap(bmp, tab_x + padding_, drawn_tab_yoff + drawn_tab_height / 2 - bmp.GetLogicalSize().y / 2, true);
 	}
 
 	// draw tab text
@@ -401,8 +386,8 @@ void SAuiTabArt::DrawTab(
 		page.active && bluetab ? wxColor(255, 255, 255) : wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
 	dc.DrawText(
 		caption,
-		tab_x + ((float)tab_width * 0.5f) - ((float)selected_textx * 0.5f),
-		drawn_tab_yoff + (drawn_tab_height) / 2 - (texty / 2));
+		tab_x + static_cast<float>(tab_width) * 0.5f - static_cast<float>(selected_textx) * 0.5f,
+		drawn_tab_yoff + drawn_tab_height / 2 - texty / 2);
 
 	// draw close button if necessary
 	if (close_button_state != wxAUI_BUTTON_STATE_HIDDEN)
@@ -411,45 +396,40 @@ void SAuiTabArt::DrawTab(
 		if (m_flags & wxAUI_NB_BOTTOM)
 			offsetY = 1;
 
-#if wxCHECK_VERSION(3, 1, 6)
-		int close_button_width  = m_activeCloseBmp.GetPreferredBitmapSizeFor(wnd).x;
-		int close_button_height = m_activeCloseBmp.GetPreferredBitmapSizeFor(wnd).y;
-#else
-		int close_button_width  = m_activeCloseBmp.GetWidth();
-		int close_button_height = m_activeCloseBmp.GetHeight();
-#endif
+		int close_button_width  = m_activeCloseBmp.GetPreferredLogicalSizeFor(wnd).x;
+		int close_button_height = m_activeCloseBmp.GetPreferredLogicalSizeFor(wnd).y;
 
 		wxRect rect(
 			tab_x + tab_width - close_button_width - padding_,
-			offsetY + (tab_height / 2) - (close_button_height / 2),
+			offsetY + tab_height / 2 - close_button_height / 2,
 			close_button_width,
 			tab_height);
 
 		IndentPressedBitmap(&rect, close_button_state);
 
-		bool close_white = (bluetab && page.active);
+		bool close_white = bluetab && page.active || app::isDarkTheme();
 
 		if (close_button_state == wxAUI_BUTTON_STATE_HOVER || close_button_state == wxAUI_BUTTON_STATE_PRESSED)
 		{
-			dc.SetPen(wxPen(drawing::darkColour(close_white ? bluetab_colour : bgcol, 2.0f)));
-			dc.SetBrush(wxBrush(drawing::lightColour(close_white ? bluetab_colour : bgcol, 1.0f)));
-			dc.DrawRectangle(rect.x, rect.y, rect.width, rect.width);
+			if (close_white)
+			{
+				dc.SetPen(wxPen(bgcol.ChangeLightness(160)));
+				dc.SetBrush(wxBrush(bgcol.ChangeLightness(125)));
+			}
+			else
+			{
+				dc.SetPen(wxPen(bgcol.ChangeLightness(60)));
+				dc.SetBrush(wxBrush(bgcol.ChangeLightness(90)));
+			}
+			dc.DrawRoundedRectangle(rect.x, rect.y, rect.width, rect.width, wnd->FromDIP(1));
 
 			const auto& bmp = close_white ? close_bitmap_white_ : m_activeCloseBmp;
-#if wxCHECK_VERSION(3, 1, 6)
 			dc.DrawBitmap(bmp.GetBitmapFor(wnd), rect.x, rect.y);
-#else
-			dc.DrawBitmap(bmp, rect.x, rect.y);
-#endif
 		}
 		else
 		{
 			const auto& bmp = close_white ? close_bitmap_white_ : m_disabledCloseBmp;
-#if wxCHECK_VERSION(3, 1, 6)
 			dc.DrawBitmap(bmp.GetBitmapFor(wnd).ConvertToDisabled(), rect.x, rect.y);
-#else
-			dc.DrawBitmap(bmp, rect.x, rect.y);
-#endif
 		}
 
 		*out_button_rect = rect;
@@ -460,9 +440,9 @@ void SAuiTabArt::DrawTab(
 	dc.DestroyClippingRegion();
 }
 
-#if wxCHECK_VERSION(3, 1, 6)
+#if wxCHECK_VERSION(3, 3, 0)
 wxSize SAuiTabArt::GetTabSize(
-	wxDC&                 dc,
+	wxReadOnlyDC&         dc,
 	wxWindow*             wnd,
 	const wxString&       caption,
 	const wxBitmapBundle& bitmap,
@@ -471,13 +451,13 @@ wxSize SAuiTabArt::GetTabSize(
 	int*                  x_extent)
 #else
 wxSize SAuiTabArt::GetTabSize(
-	wxDC& dc,
-	wxWindow* WXUNUSED(wnd),
-	const wxString& caption,
-	const wxBitmap& bitmap,
-	bool WXUNUSED(active),
-	int close_button_state,
-	int* x_extent)
+	wxDC&                 dc,
+	wxWindow*             wnd,
+	const wxString&       caption,
+	const wxBitmapBundle& bitmap,
+	bool                  WXUNUSED(active),
+	int                   close_button_state,
+	int*                  x_extent)
 #endif
 {
 	wxCoord measured_textx, measured_texty, tmp;
@@ -491,42 +471,26 @@ wxSize SAuiTabArt::GetTabSize(
 	wxCoord tab_width  = measured_textx;
 	wxCoord tab_height = measured_texty;
 
-#if wxCHECK_VERSION(3, 1, 6)
 	// if close buttons are enabled, add space for one
 	if (close_buttons_)
-		tab_width += m_activeCloseBmp.GetPreferredBitmapSizeFor(wnd).x + padding_;
+		tab_width += wnd->FromPhys(m_activeCloseBmp.GetPreferredBitmapSizeFor(wnd).x) + padding_;
 
 	// if there's a bitmap, add space for it
 	if (bitmap.IsOk())
 	{
-		tab_width += bitmap.GetPreferredBitmapSizeFor(wnd).x;
+		tab_width += wnd->FromPhys(bitmap.GetPreferredBitmapSizeFor(wnd).x);
 		tab_width += padding_; // right side bitmap padding
-		tab_height = wxMax(tab_height, bitmap.GetPreferredBitmapSizeFor(wnd).y);
+		tab_height = wxMax(tab_height, wnd->FromPhys(bitmap.GetPreferredBitmapSizeFor(wnd).y));
 	}
 	else if (tabs_condensed)
-		tab_width += (padding_ * 2); // a bit extra padding if there isn't an icon in condensed mode
-#else
-	// if close buttons are enabled, add space for one
-	if (close_buttons_)
-		tab_width += m_activeCloseBmp.GetWidth() + padding_;
-
-	// if there's a bitmap, add space for it
-	if (bitmap.IsOk())
-	{
-		tab_width += bitmap.GetWidth();
-		tab_width += padding_; // right side bitmap padding
-		tab_height = wxMax(tab_height, bitmap.GetHeight());
-	}
-	else if (tabs_condensed)
-		tab_width += (padding_ * 2); // a bit extra padding if there isn't an icon in condensed mode
-#endif
+		tab_width += padding_ * 2; // a bit extra padding if there isn't an icon in condensed mode
 
 	// add padding
-	tab_width += (padding_ * 2);
-	tab_height += ui::scalePx(10);
+	tab_width += padding_ * 2;
+	tab_height += 10;
 
 	// minimum width
-	int min_width = tabs_condensed ? ui::scalePx(48) : ui::scalePx(64);
+	int min_width = tabs_condensed ? 48 : 64;
 	if (tab_width < min_width)
 		tab_width = min_width;
 
@@ -547,25 +511,39 @@ void SAuiTabArt::SetSelectedFont(const wxFont& font)
 //
 // -----------------------------------------------------------------------------
 
-SAuiDockArt::SAuiDockArt()
+SAuiDockArt::SAuiDockArt(const wxWindow* window)
 {
 	caption_back_colour_ = drawing::darkColour(drawing::systemPanelBGColour(), 0.0f);
 
-	wxColour textColour    = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT);
-	float    r             = ((float)textColour.Red() * 0.2f) + ((float)caption_back_colour_.Red() * 0.8f);
-	float    g             = ((float)textColour.Green() * 0.2f) + ((float)caption_back_colour_.Green() * 0.8f);
-	float    b             = ((float)textColour.Blue() * 0.2f) + ((float)caption_back_colour_.Blue() * 0.8f);
+	wxColour textColour = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT);
+	float    r = static_cast<float>(textColour.Red()) * 0.2f + static_cast<float>(caption_back_colour_.Red()) * 0.8f;
+	float g = static_cast<float>(textColour.Green()) * 0.2f + static_cast<float>(caption_back_colour_.Green()) * 0.8f;
+	float b = static_cast<float>(textColour.Blue()) * 0.2f + static_cast<float>(caption_back_colour_.Blue()) * 0.8f;
 	caption_accent_colour_ = wxColor(r, g, b);
 
 	m_activeCloseBitmap   = icons::getInterfaceIcon("cross");
 	m_inactiveCloseBitmap = icons::getInterfaceIcon("cross"); //.ConvertToDisabled();
 
-	if (global::win_version_major >= 10)
+	if (global::win_version_major >= 10 && !app::isDarkTheme())
 		m_sashBrush = wxBrush(col_w10_bg);
 
-	m_captionSize = ui::scalePxU(19);
-	m_sashSize    = ui::scalePxU(4);
-	m_buttonSize  = ui::scalePx(16);
+#ifdef __WXMSW__
+	m_captionSize = window->FromDIP(16);
+#else
+	{
+		// Get line height of the system font
+		wxClientDC dc(const_cast<wxWindow*>(window));
+		dc.SetFont(wxFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT)));
+		m_captionSize = dc.GetCharHeight() + window->FromDIP(4);
+	}
+#endif
+
+	m_sashSize    = window->FromDIP(4);
+	m_buttonSize  = window->FromDIP(16);
+	m_captionFont = wxFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
+
+	wxColor borderColour = drawing::systemPanelBGColour().ChangeLightness(app::isDarkTheme() ? 115 : 75);
+	m_borderPen          = wxPen(borderColour);
 }
 
 SAuiDockArt::~SAuiDockArt() = default;
@@ -578,10 +556,6 @@ void SAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
 	dc.SetBrush(wxBrush(caption_back_colour_));
 	dc.DrawRectangle(rect.x, rect.y, rect.width, rect.height);
 
-	// dc.SetPen(m_borderPen);
-	// dc.SetBrush(wxBrush(Drawing::darkColour(caption_back_colour_, 2.0f)));
-	// dc.DrawRectangle(rect.x, rect.y, rect.width, rect.height);
-
 	wxColor sepCol;
 	int     l = ColRGBA(caption_back_colour_).greyscale().r;
 	if (l < 100)
@@ -589,26 +563,15 @@ void SAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
 	else
 		sepCol = drawing::darkColour(caption_back_colour_, 2.0f);
 
-	// dc.SetPen(wxPen(sepCol));
-	// dc.DrawLine(rect.x, rect.y + rect.height - 1, rect.x + rect.width, rect.y + rect.height - 1);
+	auto px2 = window->FromDIP(2);
+	auto px3 = window->FromDIP(3);
+	auto px5 = window->FromDIP(8);
 
-	auto px2 = ui::scalePx(2);
-	auto px3 = ui::scalePx(3);
-	auto px5 = ui::scalePx(5);
-
-	dc.SetBrush(wxBrush(sepCol));
-	dc.DrawRectangle(rect.x, rect.y, rect.width, rect.height + 1);
-
-#if wxCHECK_VERSION(3, 1, 6)
 	const auto& icon = pane.icon.GetBitmap(wxDefaultSize);
-#else
-	const auto& icon = pane.icon;
-#endif
 
 	int caption_offset = 0;
 	if (icon.IsOk())
 	{
-#if wxCHECK_VERSION(3, 1, 0)
 		// Ensure the icon fits into the title bar.
 		wxSize iconSize = icon.GetSize();
 		if (iconSize.y > rect.height)
@@ -619,9 +582,6 @@ void SAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
 		// Draw the icon centered vertically
 		int xOffset = window->FromDIP(2);
 		dc.DrawBitmap(icon, rect.x + xOffset, rect.y + (rect.height - icon.GetHeight()) / 2, true);
-#else
-		DrawIcon(dc, rect, pane);
-#endif
 		caption_offset += icon.GetWidth() + px3;
 	}
 
@@ -642,16 +602,7 @@ void SAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
 	dc.GetTextExtent(draw_text, &w, &h);
 
 	dc.SetClippingRegion(clip_rect);
-#ifdef __WXMSW__
-	dc.DrawText(draw_text, rect.x + px5 + caption_offset, rect.y + (rect.height / 2) - (h / 2));
-#else
-	dc.DrawText(draw_text, rect.x + px5 + caption_offset, rect.y + (rect.height / 2) - (h / 2) + 1);
-#endif
-
-	// dc.SetPen(wxPen(captionAccentColour));
-	// dc.DrawLine(rect.x + w + 8, rect.y + (rect.height / 2) - 1, rect.x + rect.width - 16, rect.y + (rect.height / 2)
-	// - 1); dc.DrawLine(rect.x + w + 8, rect.y + (rect.height / 2) + 1, rect.x + rect.width - 16, rect.y + (rect.height
-	// / 2) + 1);
+	dc.DrawText(draw_text, rect.x + px5 + caption_offset, rect.y + rect.height - h);
 
 	dc.DestroyClippingRegion();
 }
@@ -664,11 +615,7 @@ void SAuiDockArt::DrawPaneButton(
 	const wxRect&  _rect,
 	wxAuiPaneInfo& pane)
 {
-#if wxCHECK_VERSION(3, 1, 6)
 	wxBitmapBundle bmp;
-#else
-	wxBitmap bmp;
-#endif
 
 	bool active = true;
 	switch (button)
@@ -716,17 +663,8 @@ void SAuiDockArt::DrawPaneButton(
 		break;
 	}
 
-
-	wxRect rect = _rect;
-
-	int old_y = rect.y;
-#if wxCHECK_VERSION(3, 1, 6)
-	rect.y = rect.y + (rect.height / 2) - (bmp.GetPreferredBitmapSizeFor(window).y / 2);
-#else
-	rect.y = rect.y + (rect.height / 2) - (bmp.GetHeight() / 2);
-#endif
-	rect.height = old_y + rect.height - rect.y - 1;
-
+	auto bmp_size = bmp.GetPreferredLogicalSizeFor(window);
+	auto rect     = wxRect(_rect.x, _rect.y + _rect.height - bmp_size.y, bmp_size.x, bmp_size.y);
 
 	if (button_state == wxAUI_BUTTON_STATE_PRESSED)
 	{
@@ -736,20 +674,18 @@ void SAuiDockArt::DrawPaneButton(
 
 	if (button_state == wxAUI_BUTTON_STATE_HOVER || button_state == wxAUI_BUTTON_STATE_PRESSED)
 	{
-		dc.SetPen(wxPen(drawing::darkColour(drawing::systemPanelBGColour(), 2.0f)));
-		dc.SetBrush(wxBrush(drawing::lightColour(drawing::systemPanelBGColour(), 1.0f)));
-		dc.DrawRectangle(rect.x, rect.y, rect.width + 1, rect.width + 1);
-
-		bmp    = m_activeCloseBitmap;
-		active = true;
+		if (app::isDarkTheme())
+		{
+			dc.SetPen(wxPen(caption_back_colour_.ChangeLightness(160)));
+			dc.SetBrush(wxBrush(caption_back_colour_.ChangeLightness(125)));
+		}
+		else
+		{
+			dc.SetPen(wxPen(caption_back_colour_.ChangeLightness(60)));
+			dc.SetBrush(wxBrush(caption_back_colour_.ChangeLightness(90)));
+		}
+		dc.DrawRoundedRectangle(rect.x, rect.y, rect.width, rect.height, window->FromDIP(1));
 	}
 
-
-	// draw the button itself
-#if wxCHECK_VERSION(3, 1, 6)
-	dc.DrawBitmap(
-		active ? bmp.GetBitmapFor(window) : bmp.GetBitmapFor(window).ConvertToDisabled(), rect.x, rect.y, true);
-#else
-	dc.DrawBitmap(bmp, rect.x, rect.y, true);
-#endif
+	dc.DrawBitmap(bmp.GetBitmapFor(window), rect.x, rect.y, true);
 }
