@@ -33,6 +33,7 @@
 // -----------------------------------------------------------------------------
 #include "Main.h"
 #include "SToolBar.h"
+#include "App.h"
 #include "General/SAction.h"
 #include "OpenGL/Drawing.h"
 #include "SToolBarButton.h"
@@ -153,7 +154,9 @@ public:
 // SToolBarGroup class constructor
 // -----------------------------------------------------------------------------
 SToolBarGroup::SToolBarGroup(SToolBar* parent, const wxString& name, bool force_name) :
-	wxPanel(parent, -1), name_{ name }, orientation_{ parent->orientation() }
+	wxPanel(parent, -1),
+	name_{ name },
+	orientation_{ parent->orientation() }
 {
 	// Check if hidden
 	wxString tb_hidden = toolbars_hidden;
@@ -308,8 +311,8 @@ void SToolBarGroup::addSeparator()
 {
 	bool horizontal = orientation_ == wxHORIZONTAL;
 
-	auto* sep = horizontal ? static_cast<wxWindow*>(new SToolBarHSeparator(this)) :
-							 static_cast<wxWindow*>(new SToolBarVSeparator(this));
+	auto* sep = horizontal ? static_cast<wxWindow*>(new SToolBarHSeparator(this))
+						   : static_cast<wxWindow*>(new SToolBarVSeparator(this));
 
 	if (horizontal)
 		GetSizer()->Add(sep, 0, wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, ui::px(ui::Size::PadMinimum));
@@ -431,7 +434,9 @@ void SToolBarGroup::onButtonClicked(wxCommandEvent& e)
 // SToolBar class constructor
 // -----------------------------------------------------------------------------
 SToolBar::SToolBar(wxWindow* parent, bool main_toolbar, wxOrientation orientation) :
-	wxPanel(parent, -1), main_toolbar_{ main_toolbar }, orientation_{ orientation }
+	wxPanel(parent, -1),
+	main_toolbar_{ main_toolbar },
+	orientation_{ orientation }
 {
 	// Enable double buffering to avoid flickering
 #ifdef __WXMSW__
@@ -442,9 +447,18 @@ SToolBar::SToolBar(wxWindow* parent, bool main_toolbar, wxOrientation orientatio
 	SetDoubleBuffered(true);
 #endif
 
-	// Set background colour
-	wxPanel::SetBackgroundColour(
-		(main_toolbar && global::win_version_major >= 10) ? wxColor(250, 250, 250) : drawing::systemPanelBGColour());
+		// Set background colour
+#ifdef __WXMSW__
+	if (main_toolbar)
+	{
+		if (app::isDarkTheme())
+			wxWindowBase::SetBackgroundColour(wxColor(0x262626));
+		else if (global::win_version_major >= 10)
+			wxWindowBase::SetBackgroundColour(wxColor(250, 250, 250));
+		else
+			wxWindowBase::SetBackgroundColour(drawing::systemPanelBGColour());
+	}
+#endif
 
 	// Create sizer
 	auto* sizer = new wxBoxSizer(orientation);
