@@ -489,9 +489,7 @@ Plane math::planeFromTriangle(Vec3d p1, Vec3d p2, Vec3d p3)
 // -----------------------------------------------------------------------------
 bool math::colinear(double x1, double y1, double x2, double y2, double x3, double y3)
 {
-	double a = x1 * (y2 - y3) +
-	x2 * (y3 - y1) +
-	x3 * (y1 - y2);
+	double a = x1 * (y2 - y3) + x2 * (y3 - y1) + x3 * (y1 - y2);
 
 	return a == 0;
 }
